Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetCollection ¶
func GetCollection( db *sql.DB, rows *sql.Rows, table string, embedsTo, embedsFrom []oracleManager.Reference, ) ([]bson.D, error)
GetCollection generates, based on an oracle database connection, a series of documents with the data from a table or query. It will embed all references in the embeds* arrays with the whole document related to the reference. This function takes in a database connection, an open query with data to be turned into the document, the table related to the query, and the list of references that should be embed.
This function does recursion, and does not check if the embed references loop back to an initial table in order to stop infinite recursion.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.